@@ -1,7 +1,7 @@
 from typing import Callable, Dict, Optional
 
-from .credential_managers import credential_managers
-from .dummy import dummy_credential_manager
+from laituri.docker.credential_manager.credential_managers import credential_managers
+from laituri.docker.credential_manager.dummy import get_dummy_credential_manager
 
 
 def _noop_log_status(message: str):
@@ -12,7 +12,7 @@ def get_credential_manager(
     *,
     image: str,
     registry_credentials: Optional[Dict] = None,
-    log_status: Optional[Callable] = _noop_log_status
+    log_status: Callable = _noop_log_status
 ):
     """
     Get a credential context manager object based on the registry credentials dictionary passed in.
@@ -26,19 +26,18 @@ def get_credential_manager(
     :raises DockerLoginFailed
     :return: ContextManager
     """
-    manager_kwargs = dict(
-        image=image,
-        registry_credentials=registry_credentials,
-        log_status=log_status,
-    )
     if not isinstance(registry_credentials, dict):  # no credentials to manage
-        return dummy_credential_manager(**manager_kwargs)
+        return get_dummy_credential_manager()
 
     credentials_type = registry_credentials.get('type')
     version = registry_credentials.get('version')
-    manager = credential_managers.get((credentials_type, str(version)))
+    manager = credential_managers.get((str(credentials_type), str(version)))
     if manager:
-        return manager(**manager_kwargs)
+        return manager(
+            image=image,
+            registry_credentials=registry_credentials,
+            log_status=log_status,
+        )
 
-    log_status('Unable to parse %s version %s registry credentials; upcoming action may fail.' % (type, version))
-    return dummy_credential_manager(**manager_kwargs)
+    log_status(f'Unable to parse {type} version {version} registry credentials; upcoming action may fail.')
+    return get_dummy_credential_manager()
