@@ -1,10 +1,11 @@
 import logging
+import shutil
 import subprocess
 from contextlib import contextmanager
 from typing import Callable, Dict
 
 from laituri import settings
-from .errors import DockerLoginFailed
+from laituri.docker.credential_manager.errors import DockerLoginFailed, InvalidDockerCommand
 
 log = logging.getLogger(__name__)
 
@@ -24,9 +25,18 @@ def docker_v1_credential_manager(
             password=str(registry_credentials['password']),
         )
     except DockerLoginFailed as dlf:
-        raise DockerLoginFailed('Failed Docker login to %s: %s' % (domain, str(dlf))) from dlf
-    yield
-    docker_logout(domain)
+        raise DockerLoginFailed(f'Failed Docker login to {domain}: {str(dlf)}') from dlf
+    try:
+        yield
+    finally:
+        docker_logout(domain)
+
+
+def get_docker_command() -> str:
+    cmd = shutil.which(settings.DOCKER_COMMAND)
+    if not cmd:
+        raise InvalidDockerCommand(f"Invalid Docker command: {cmd}")
+    return cmd
 
 
 def docker_login(domain: str, username: str, password: str) -> bool:
@@ -34,14 +44,13 @@ def docker_login(domain: str, username: str, password: str) -> bool:
     Use Docker command-line client to login to the specified image registry.
     """
     args = [
-        '/usr/bin/env',
-        settings.DOCKER_COMMAND,
+        get_docker_command(),
         'login',
         '--username', username,
         '--password-stdin',
         domain,
     ]
-    log.info('Running `%s`' % ' '.join(args))
+    log.debug(f"Running `{' '.join(args)}`")
     proc = subprocess.Popen(args, stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
     try:
         cmd_input = (password + '\n').encode('utf-8')
@@ -62,13 +71,12 @@ def docker_logout(domain: str) -> None:
         domain = 'https://index.docker.io/v1/'
 
     try:
-        log.info('Running `docker logout %s`' % domain)
+        log.debug(f'Running `docker logout {domain}`')
         subprocess.check_call([
-            '/usr/bin/env',
-            settings.DOCKER_COMMAND,
+            get_docker_command(),
             'logout',
             domain,
         ], stderr=subprocess.STDOUT, stdout=subprocess.PIPE, timeout=settings.DOCKER_TIMEOUT)
     except subprocess.CalledProcessError as cpe:
         message = cpe.stdout.decode('utf-8', errors='ignore')
-        log.warning('Failed `docker logout %s`: %s' % (domain, message))
+        log.warning(f'Failed `docker logout {domain}`: {message}')
